@@ -4,6 +4,8 @@ debug - Greple module for debug control
 
 =head1 SYNOPSIS
 
+greple -dmc
+
 greple -Mdebug
 
 greple -Mdebug::on(getoptex)
@@ -20,6 +22,7 @@ are available.
     color       -dc  Color information
     directory   -dd  Change directory information
     file        -df  Show search file names
+    number      -dn  Show number of processing files
     misc        -dm  Pattern and other information
     option      -do  Show command option processing
     process     -dp  Exec ps command before exit
@@ -38,8 +41,8 @@ Specify required target with C<on> function like:
 
     $ greple -Mdebug::on=color,misc,option
 
-Calling C<debug::all()> enables all targets.  Exceptionally C<unused>
-is not enabled, because it immediately exits.
+Calling C<debug::on=all> enables all targets, except C<unused> and
+C<number>.
 
 Target name marked with C<-dx> can be enabled in that form.  Following
 commands are all equivalent.
@@ -62,6 +65,7 @@ L<Getopt::EX> module.
 
 package App::Greple::debug;
 
+use v5.14;
 use strict;
 use warnings;
 use Carp;
@@ -77,6 +81,7 @@ my %flags = (
     color     => \$opt_d{c},
     directory => \$opt_d{d},
     file      => \$opt_d{f},
+    number    => \$opt_d{n},
     misc      => \$opt_d{m},
     option    => \$opt_d{o},
     process   => \$opt_d{p},
@@ -85,7 +90,20 @@ my %flags = (
     unused    => \$opt_d{u},
     );
 
-my %exclude = ( unused => 1 );
+sub getoptex  { on ( getoptex  => 1 ) }
+sub getopt    { on ( getopt    => 1 ) }
+sub color     { on ( color     => 1 ) }
+sub directory { on ( directory => 1 ) }
+sub file      { on ( file      => 1 ) }
+sub number    { on ( number    => 1 ) }
+sub misc      { on ( misc      => 1 ) }
+sub option    { on ( option    => 1 ) }
+sub process   { on ( process   => 1 ) }
+sub stat      { on ( stat      => 1 ) }
+sub grep      { on ( grep      => 1 ) }
+sub unused    { on ( unused    => 1 ) }
+
+my %exclude = map { $_ => 1 } qw(unused number);
 
 my @all_flags = grep { not $exclude{$_} } sort keys %flags;
 
@@ -113,16 +131,17 @@ sub switch {
 
 my @default = qw(getoptex option);
 
-my $called = 0;
+sub switch_default {
+    switch map { $_ => $_[0] } @default;
+}
 
 sub on {
     my %arg = @_;
     delete $arg{&FILELABEL}; # no entry when called from -M otption.
 
     # Clear default setting on first call.
-    if ($called++ == 0) {
-	switch_default(0);
-    }
+    state $called;
+    $called++ or switch_default 0;
 
     if (delete $arg{'all'}) {
 	map { $arg{$_} = 1 } @all_flags;
@@ -132,11 +151,7 @@ sub on {
 }
 
 sub initialize {
-    switch_default(1);
-}
-
-sub switch_default {
-    switch map { $_ => $_[0] } @default;
+    switch_default 1;
 }
 
 1;
